import { axisLeft,
        axisBottom,
        select,
        csv,
        format,
        scaleLinear,
        scalePoint, 
        max } from 'd3';

const svg = select('svg');
const div = select("body").append("div").attr("class", "tooltip");


const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const yValue = d => d.country
  const xValue = d => d.population
  const margin = {top:40,right:40, bottom:75, left:235}
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain([0, max(data, xValue)])
  	.range([0, innerWidth])
  	.nice();
  
  const yScale = scalePoint()
  	.domain(data.map(yValue))
  	.range([0,innerHeight])
  	.padding(0.5)
  
  const g = svg.append("g")
  	.attr("transform", "translate("+margin.left+","+margin.top+")")
  
  const xAxisTickFormat = number => 
  	format(".3s")(number)
  		.replace("G","B");
  
  const xAxis =axisBottom(xScale)
  	.tickFormat(xAxisTickFormat)
  	.tickSize(-innerHeight);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  
  g.append("g")
    .call(yAxis)
  	.selectAll(".domain").remove();
  
  const xAxisG = g.append("g").call(xAxis)
  	.attr("transform", "translate(0,"+innerHeight+")")
  
  xAxisG.select(".domain").remove();
  
  xAxisG.append("text")
  	.attr("class", "axis-label")
  	.attr("y", 65)
  	.attr("x", innerWidth/2)
  	.attr("fill","black")
  	.text("Population");
  
  g.selectAll("circle").data(data)
  	.enter().append("circle")
  		.attr("cy", d => yScale(yValue(d)))
  		.attr("cx", d => xScale(xValue(d)))
  		.attr("r", 18)
  		.on("mouseover", function(d){
    		console.log(event.pageY)
    		div.style("opacity",0.8)
    		div.style("top", event.pageY+"px")
    		div.style("left", event.pageX+"px")
    		div.text(d.population)  		
  		})
  		.on("mouseout", function(d){
  			div.style("opacity",0)
  		})
  
  g.append("text")
  	.attr("y", -10)
  	.attr("class", "title")
    .text("Top Most Populous Countries");
 
  
  
  
}
  

csv("data.csv").then(data=>{
  data.forEach(d=>{
  	d.population = +d.population *1000;
  })
    render(data)
})